# StoredCredentialProfileType

Indicates the type of the stored credential profile to process recurring or unsecheduled transactions. 

## Enum

* `RECURRING` (value: `'Recurring'`)

* `UNSCHEDULED` (value: `'Unscheduled'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


